@@ -38,3 +38,15 @@ def test_io_api():
         stream.seek(0)
     with nt.assert_raises(io.UnsupportedOperation):
         stream.tell()
+    with nt.assert_raises(TypeError):
+        stream.write(b'')
+
+def test_io_isatty():
+    session = Session()
+    ctx = zmq.Context()
+    pub = ctx.socket(zmq.PUB)
+    thread = IOPubThread(pub)
+    thread.start()
+
+    stream = OutStream(session, thread, 'stdout', isatty=True)
+    assert stream.isatty()
